The function calculates points in time where large changes happen in the isotopic values. It uses the posterior distributions to estimate the probability of changes to be (absolutely or relatively) large.
getSiteStayTimes(object, siteMeans, siteSigma, intervalLengths = NULL,
print = TRUE)model of class TemporalIso
numeric vector. Isotopic mean values of sites/locations.
numeric vector. Isotopic standard deviation values of sites/locations..
numceric vector. Vector of time interval lengths. Optional (if not given equal length intervals are assumed)
boolean. If output should be printed. Defaults to TRUE.
a data.frame containing the interval starts (intStart) and ends (intEnd) of changes.